##  How to model middleware in LeanIX
Please refer to the section [Application vs. IT component](https://help.sap.com/docs/leanix/ea/application-vs-it-component-v3?locale=en-US&state=PRODUCTION&version=CLOUD) if you do not have a clear understanding of the differences between both since this is essential for the following guidelines on how middleware can be modeled.
